#include <nuon/bios.h>
#include <nuon/dma.h>
#include <nuon/video.h>
#include <nuon/mml2d.h>
#include <string.h>

//32 bit color values taken from mml2d.h

#define NTSCWHITE (0xB4808000UL)
#define WHITE (0xEB808000UL)
#define BLACK (0x10808000UL)
#define FIRST_ROW (60UL)
#define LAST_ROW (419UL)
#define NUM_COLORS (2UL)

//Use 32 bit 8-8-8-Alpha full-screen mode
#define SCREEN_WIDTH (720UL)
#define SCREEN_HEIGHT (480UL)

#define MAIN_CHANNEL_WIDTH SCREEN_WIDTH
#define MAIN_CHANNEL_HEIGHT SCREEN_HEIGHT
#define ROW_RENDER_OFFSET MAIN_CHANNEL_HEIGHT

unsigned long *mainChannelBuffer;
int localSize;

VidDisplay mainDisplay;
VidChannel mainChannel;

void vidsetup(void)
{
  mainChannel.dmaflags = ((MAIN_CHANNEL_WIDTH >> 3) << 16) | ePixDma | eCluster | (4UL<<4);
  mainChannelBuffer =
    (unsigned long *)_MemAlloc((MAIN_CHANNEL_WIDTH * MAIN_CHANNEL_HEIGHT) << 2, 512, kMemSDRAM);

  _VidSetup((void *)mainChannelBuffer,mainChannel.dmaflags, MAIN_CHANNEL_WIDTH, MAIN_CHANNEL_HEIGHT, 0);
}

void ClearScreen(unsigned long color)
{
  unsigned long x,y,numPixels;

  for(y = 0; y < MAIN_CHANNEL_HEIGHT; y = y + 8)
  {
    for (x = 0; x < MAIN_CHANNEL_WIDTH; x = x + 8)
    {
      _DMABiLinear(mainChannel.dmaflags|DMA_DIRECT_BIT, mainChannelBuffer, (8<<16)|x, (8<<16)|y, (void *)color);
    }
  }
}

int main(void)
{
  bool bJoystickActive;
  int buttonState, y;

  vidsetup();

  //Detect joysticks
  _DeviceDetect(0);
  _DeviceDetect(1);

  _Controller[1].buttons = 0;

  if(_Controller[1].status)
  {
    bJoystickActive = true;
  }
  else
  {
    bJoystickActive = false; 
  }


  while(1)
  {
    buttonState = 0;

    
    if(ButtonZ(_Controller[1]))
    {
      buttonState |= 0x08;
    }

    if(ButtonStart(_Controller[1]))
    {
      buttonState |= 0x04;
    }

    if(ButtonA(_Controller[1]))
    {
      buttonState |= 0x02;
    }

    if(ButtonB(_Controller[1]))
    {
      buttonState |= 0x01;
    }

    switch(buttonState)
    {
      case 0:
        ClearScreen(kWhite);
        break;
      case 1:
        ClearScreen(kBlue);
        break;
      case 2:
        ClearScreen(kRed);
        break;
      case 3:
        ClearScreen(kBlack);
        break;
      default:
        if(_Controller[1].buttons)
        {
          ClearScreen(kYellow);
        }
        else
        {
          ClearScreen(kGreen);
        }
	break;
    }
  }

  y = 0xDEADBEEF;

  return 1;
}
